Example gallery
===============

Basic examples
--------------

.. toctree::
   :maxdepth: 1

   gallery/capitals
   gallery/footprint
   gallery/airports
   gallery/terminal
   gallery/mercantour
   gallery/switzerland

Advanced examples
-----------------

.. toctree::
   :maxdepth: 1

   gallery/bayern
   gallery/tokyo_metro
